@@ -19,7 +19,6 @@ from mypy_boto3_mediatailor.paginator import (
     GetChannelSchedulePaginator,
     ListChannelsPaginator,
     ListPlaybackConfigurationsPaginator,
-    ListProgramsPaginator,
     ListSourceLocationsPaginator,
     ListVodSourcesPaginator,
 )
@@ -46,7 +45,6 @@ from mypy_boto3_mediatailor.type_defs import (
     HttpPackageConfigurationTypeDef,
     ListChannelsResponseTypeDef,
     ListPlaybackConfigurationsResponseTypeDef,
-    ListProgramsResponseTypeDef,
     ListSourceLocationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListVodSourcesResponseTypeDef,
@@ -84,7 +82,7 @@ class Exceptions:
 
 class MediaTailorClient:
     """
-    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client)
+    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client)
     """
 
     meta: ClientMeta
@@ -92,7 +90,7 @@ class MediaTailorClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         """
 
     def create_channel(
@@ -103,7 +101,7 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateChannelResponseTypeDef:
         """
-        [Client.create_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        [Client.create_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
         """
 
     def create_program(
@@ -116,7 +114,7 @@ class MediaTailorClient:
         AdBreaks: List["AdBreakTypeDef"] = None,
     ) -> CreateProgramResponseTypeDef:
         """
-        [Client.create_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        [Client.create_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         """
 
     def create_source_location(
@@ -128,7 +126,7 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateSourceLocationResponseTypeDef:
         """
-        [Client.create_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        [Client.create_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         """
 
     def create_vod_source(
@@ -139,63 +137,63 @@ class MediaTailorClient:
         Tags: Dict[str, str] = None,
     ) -> CreateVodSourceResponseTypeDef:
         """
-        [Client.create_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        [Client.create_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         """
 
     def delete_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Client.delete_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        [Client.delete_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
         """
 
     def delete_channel_policy(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Client.delete_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        [Client.delete_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         """
 
     def delete_playback_configuration(self, Name: str) -> Dict[str, Any]:
         """
-        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         """
 
     def delete_program(self, ChannelName: str, ProgramName: str) -> Dict[str, Any]:
         """
-        [Client.delete_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        [Client.delete_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         """
 
     def delete_source_location(self, SourceLocationName: str) -> Dict[str, Any]:
         """
-        [Client.delete_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        [Client.delete_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         """
 
     def delete_vod_source(self, SourceLocationName: str, VodSourceName: str) -> Dict[str, Any]:
         """
-        [Client.delete_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        [Client.delete_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         """
 
     def describe_channel(self, ChannelName: str) -> DescribeChannelResponseTypeDef:
         """
-        [Client.describe_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        [Client.describe_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         """
 
     def describe_program(
         self, ChannelName: str, ProgramName: str
     ) -> DescribeProgramResponseTypeDef:
         """
-        [Client.describe_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        [Client.describe_program documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         """
 
     def describe_source_location(
         self, SourceLocationName: str
     ) -> DescribeSourceLocationResponseTypeDef:
         """
-        [Client.describe_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        [Client.describe_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         """
 
     def describe_vod_source(
         self, SourceLocationName: str, VodSourceName: str
     ) -> DescribeVodSourceResponseTypeDef:
         """
-        [Client.describe_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        [Client.describe_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         """
 
     def generate_presigned_url(
@@ -206,12 +204,12 @@ class MediaTailorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         """
 
     def get_channel_policy(self, ChannelName: str) -> GetChannelPolicyResponseTypeDef:
         """
-        [Client.get_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        [Client.get_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         """
 
     def get_channel_schedule(
@@ -222,57 +220,50 @@ class MediaTailorClient:
         NextToken: str = None,
     ) -> GetChannelScheduleResponseTypeDef:
         """
-        [Client.get_channel_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        [Client.get_channel_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
         """
 
     def get_playback_configuration(self, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
         """
-        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         """
 
     def list_channels(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListChannelsResponseTypeDef:
         """
-        [Client.list_channels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        [Client.list_channels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         """
 
     def list_playback_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
-        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
-        """
-
-    def list_programs(
-        self, ChannelName: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListProgramsResponseTypeDef:
-        """
-        [Client.list_programs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_programs)
+        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         """
 
     def list_source_locations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListSourceLocationsResponseTypeDef:
         """
-        [Client.list_source_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        [Client.list_source_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         """
 
     def list_vod_sources(
         self, SourceLocationName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListVodSourcesResponseTypeDef:
         """
-        [Client.list_vod_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        [Client.list_vod_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         """
 
     def put_channel_policy(self, ChannelName: str, Policy: str) -> Dict[str, Any]:
         """
-        [Client.put_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        [Client.put_channel_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
         """
 
     def put_playback_configuration(
@@ -293,34 +284,34 @@ class MediaTailorClient:
         VideoContentSourceUrl: str = None,
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
-        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         """
 
     def start_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Client.start_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        [Client.start_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         """
 
     def stop_channel(self, ChannelName: str) -> Dict[str, Any]:
         """
-        [Client.stop_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        [Client.stop_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         """
 
     def update_channel(
         self, ChannelName: str, Outputs: List[RequestOutputItemTypeDef]
     ) -> UpdateChannelResponseTypeDef:
         """
-        [Client.update_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        [Client.update_channel documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         """
 
     def update_source_location(
@@ -331,7 +322,7 @@ class MediaTailorClient:
         DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None,
     ) -> UpdateSourceLocationResponseTypeDef:
         """
-        [Client.update_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        [Client.update_source_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         """
 
     def update_vod_source(
@@ -341,7 +332,7 @@ class MediaTailorClient:
         VodSourceName: str,
     ) -> UpdateVodSourceResponseTypeDef:
         """
-        [Client.update_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        [Client.update_vod_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         """
 
     @overload
@@ -349,13 +340,13 @@ class MediaTailorClient:
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Paginator.GetChannelSchedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+        [Paginator.GetChannelSchedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+        [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
         """
 
     @overload
@@ -363,13 +354,7 @@ class MediaTailorClient:
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
-        """
-
-    @overload
-    def get_paginator(self, operation_name: Literal["list_programs"]) -> ListProgramsPaginator:
-        """
-        [Paginator.ListPrograms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrograms)
+        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         """
 
     @overload
@@ -377,11 +362,11 @@ class MediaTailorClient:
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Paginator.ListSourceLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+        [Paginator.ListSourceLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Paginator.ListVodSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+        [Paginator.ListVodSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
         """
