@@ -11,7 +11,6 @@ Usage::
         GetChannelSchedulePaginator,
         ListChannelsPaginator,
         ListPlaybackConfigurationsPaginator,
-        ListProgramsPaginator,
         ListSourceLocationsPaginator,
         ListVodSourcesPaginator,
     )
@@ -21,7 +20,6 @@ Usage::
     get_channel_schedule_paginator: GetChannelSchedulePaginator = client.get_paginator("get_channel_schedule")
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
-    list_programs_paginator: ListProgramsPaginator = client.get_paginator("list_programs")
     list_source_locations_paginator: ListSourceLocationsPaginator = client.get_paginator("list_source_locations")
     list_vod_sources_paginator: ListVodSourcesPaginator = client.get_paginator("list_vod_sources")
     ```
@@ -34,7 +32,6 @@ from mypy_boto3_mediatailor.type_defs import (
     GetChannelScheduleResponseTypeDef,
     ListChannelsResponseTypeDef,
     ListPlaybackConfigurationsResponseTypeDef,
-    ListProgramsResponseTypeDef,
     ListSourceLocationsResponseTypeDef,
     ListVodSourcesResponseTypeDef,
     PaginatorConfigTypeDef,
@@ -44,7 +41,6 @@ __all__ = (
     "GetChannelSchedulePaginator",
     "ListChannelsPaginator",
     "ListPlaybackConfigurationsPaginator",
-    "ListProgramsPaginator",
     "ListSourceLocationsPaginator",
     "ListVodSourcesPaginator",
 )
@@ -52,7 +48,7 @@ __all__ = (
 
 class GetChannelSchedulePaginator(Boto3Paginator):
     """
-    [Paginator.GetChannelSchedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+    [Paginator.GetChannelSchedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
     """
 
     def paginate(
@@ -62,70 +58,57 @@ class GetChannelSchedulePaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetChannelScheduleResponseTypeDef]:
         """
-        [GetChannelSchedule.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
+        [GetChannelSchedule.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule.paginate)
         """
 
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListChannelsResponseTypeDef]:
         """
-        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
+        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels.paginate)
         """
 
 
 class ListPlaybackConfigurationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+    [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPlaybackConfigurationsResponseTypeDef]:
         """
-        [ListPlaybackConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
-        """
-
-
-class ListProgramsPaginator(Boto3Paginator):
-    """
-    [Paginator.ListPrograms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrograms)
-    """
-
-    def paginate(
-        self, ChannelName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProgramsResponseTypeDef]:
-        """
-        [ListPrograms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrograms.paginate)
+        [ListPlaybackConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations.paginate)
         """
 
 
 class ListSourceLocationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSourceLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+    [Paginator.ListSourceLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSourceLocationsResponseTypeDef]:
         """
-        [ListSourceLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
+        [ListSourceLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations.paginate)
         """
 
 
 class ListVodSourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListVodSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+    [Paginator.ListVodSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
     """
 
     def paginate(
         self, SourceLocationName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListVodSourcesResponseTypeDef]:
         """
-        [ListVodSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.28/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
+        [ListVodSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.29/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources.paginate)
         """
